#
# spec file for package python-social-auth-app-django
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-social-auth-app-django
Version:        5.4.2
Release:        1.2
Summary:        Python Social Authentication, Django integration
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/python-social-auth/social-app-django
Source:         https://files.pythonhosted.org/packages/source/s/social-auth-app-django/social-auth-app-django-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module python-jose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module social-auth-core >= 4.1.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-python-jose
Requires:       python-social-auth-core >= 4.1.0
BuildArch:      noarch
%python_subpackages

%description
This is the Django component of the python-social-auth ecosystem,
it implements the needed functionality to integrate social-auth-core
in a Django based project.

%prep
%setup -q -n social-auth-app-django-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF8
mkdir tests/templates
echo -n test > tests/templates/test.html
%python_exec manage.py test --verbosity 2

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/social_django/
%{python_sitelib}/social_auth_app_django-*/

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 5.4.2:
  * Fixed `UserSocialAuth` creation by allowing `JSONField` to be
    blank
  * Fixed the assumption that UID can only be an integer
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 5.4.1 (bsc#1223373, CVE-2024-32879):
  * Added reverse migration for JSON field
  * Fixed improper handling of case sensitivity with
    MySQL/MariaDB (CVE-2024-32879)
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 5.4.0:
  * Improved JSON field migration performance
  * Introduce configuration to request POST only requests for
    social authentication
  * Updated list of supported Django and Python versions
  * Uses Django native JSON field
  * Removed support for Django<3.2
  * Fixed missing migration issue
  * Compatibility with recent Django and Python versions
  * Coding style improvements
  * Improved error handling in SocialAuthExceptionMiddleware
* Tue Mar 28 2023 John Vandenberg <jayvdb@gmail.com>
- Add dependency python-jose
* Wed Apr 20 2022 pgajdos@suse.com
- python-mock is not required for build
* Wed Aug 11 2021 Markéta Machová <mmachova@suse.com>
- Update to version 5.0.0
  * Removed compat shims for obsolete Django versions
  * Switch from deprecated django.conf.urls.url to django.urls.path
  * Drop support for Python 2
  * Django generic JSONField support
  * Django 3.2+ compatibility
* Wed Aug 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build on leap as we require too new django for py2
* Wed Jul  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.0.0
  * Dropped support for older Django versions (1.8, 1.9, 1.10, 2.0)
  * Fix `TypeError` when continuing a pipeline in Django 2.1
* Tue Jun  2 2020 John Vandenberg <jayvdb@gmail.com>
- Remove merged pr_197.patch
- Update to version 3.4.0
  * Correct release mechanism
- from v3.3.0
  * Updated release and tests mechanism
- from v3.2.0
  * Increase social-core dependency version to 3.3.0
  * Implement `get` and `delete` class methods for `DjangoNonceMixin`
  * Added `created` and `modified` fields to `UserSocialAuth` model
* Wed Apr 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Export lang to fix build with older openSUSE releases
* Wed Apr 10 2019 John Vandenberg <jayvdb@gmail.com>
- Add pr_197.patch to fix bug with Django 2.2
* Fri Nov 30 2018 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 3.1.0
  * Updated JSONField.from_db_value signature to support multiple
    Django versions by accepting just the needed parameters.
- Changes from version 3.0.0
  * Reduce log level of exceptions to INFO if messages app is installed
  * Encode association secret with encodebytes if available
  * Decode association secret for proper storage
  * Remove obsolete code from JSONField
  * Pass user as keyword argument to do_complete
  * Cleanup username when using email as username
  * Drop Python 3.3 support
  * Correct spelling errors
  * Correct version that renamed field.rel
  * Reduce error logs in SocialAuthExceptionMiddleware
* Wed Aug  1 2018 tchvatal@suse.com
- Build properly with python2
- Sort out with spec-cleaner to have unified look
* Wed Jul 25 2018 sean.marlow@suse.com
- Remove devel module dependency.
- Move license in spec.
* Thu Jan 25 2018 sean.marlow@suse.com
- Initial release. v2.1.0
